Welcome to mirror list, hosted at ThFree Co, Russian Federation.

gitlab.com/gitlab-org/gitlab-pages.git - Unnamed repository; edit this file 'description' to name the repository.
summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorKamil Trzciński <ayufan@ayufan.eu>2020-10-07 16:53:50 +0300
committerKamil Trzciński <ayufan@ayufan.eu>2020-10-13 00:13:32 +0300
commite7a571d304492cbca9f54d10f08374100f4cd66a (patch)
tree8a54ac215132d9c887821d7a69e246012d415c7d /metrics
parent61acef8cafafbab2bf1689a97fecddddbd726152 (diff)
Update metrics
Diffstat (limited to 'metrics')
-rw-r--r--metrics/metrics.go41
1 files changed, 10 insertions, 31 deletions
diff --git a/metrics/metrics.go b/metrics/metrics.go
index d2243fae..db7cae9a 100644
--- a/metrics/metrics.go
+++ b/metrics/metrics.go
@@ -164,41 +164,22 @@ var (
[]string{"state"},
)
- // ZipServingArchiveCache is the number of zip archive cache hits/misses
- ZipServingArchiveCache = prometheus.NewCounterVec(
+ // ZipCacheRequests is the number of cache hits/misses
+ ZipCacheRequests = prometheus.NewCounterVec(
prometheus.CounterOpts{
Name: "gitlab_pages_zip_cache_requests",
Help: "The number of zip archives cache hits/misses",
},
- []string{"cache"},
+ []string{"op", "cache"},
)
- // ZipServingArchiveDataOffsetCache is the number of zip archive
- // data offset cache hits/misses
- ZipServingArchiveDataOffsetCache = prometheus.NewCounterVec(
- prometheus.CounterOpts{
- Name: "gitlab_pages_zip_data_offset_cache_requests",
- Help: "The number of zip archive data offset cache hits/misses",
- },
- []string{"cache"},
- )
-
- // ZipServingArchiveReadlinkCache is the number of zip archive Readlink
- // cache hits/misses
- ZipServingArchiveReadlinkCache = prometheus.NewCounterVec(
- prometheus.CounterOpts{
- Name: "gitlab_pages_zip_readlink_cache_requests",
- Help: "The number of zip archives Readlink cache hits/misses",
- },
- []string{"cache"},
- )
-
- // ZipCachedArchives is the number of zip archives currently in the cache
- ZipCachedArchives = prometheus.NewGauge(
+ // ZipCachedArchives is the number of entries in the cache
+ ZipCachedEntries = prometheus.NewGaugeVec(
prometheus.GaugeOpts{
- Name: "gitlab_pages_zip_cached_archives",
- Help: "The number of zip archives currently in the cache",
+ Name: "gitlab_pages_zip_cached_entries",
+ Help: "The number of entries in the cache",
},
+ []string{"op"},
)
// ZipArchiveEntriesCached is the number of files per zip archive currently
@@ -245,10 +226,8 @@ func MustRegister() {
HTTPRangeOpenRequests,
ZipOpened,
ZipOpenedEntriesCount,
- ZipServingArchiveCache,
- ZipServingArchiveDataOffsetCache,
- ZipServingArchiveReadlinkCache,
+ ZipCacheRequests,
ZipArchiveEntriesCached,
- ZipCachedArchives,
+ ZipCachedEntries,
)
}